@@ -46,11 +46,6 @@ bool focusing = TRUE;
 bool as_an_at = TRUE;
 		/* Whether a 0x0A byte should be shown as a ^@ instead of a ^J. */
 
-int margin = 0;
-		/* The amount of space reserved at the left for line numbers. */
-int editwincols = -1;
-		/* The number of usable columns in the edit window: COLS - margin. */
-
 bool suppress_cursorpos = FALSE;
 		/* Should we skip constant position display for current keystroke? */
 
@@ -98,18 +93,22 @@ char *present_path = NULL;
 
 unsigned flags[4] = {0, 0, 0, 0};
 		/* Our flag containing the states of all global options. */
+
 WINDOW *topwin = NULL;
-		/* The top portion of the window, where we display the version
-		 * number of nano, the name of the current file, and whether the
-		 * current file has been modified. */
+		/* The top portion of the screen, showing the version number of nano,
+		 * the name of the file, and whether the buffer was modified. */
 WINDOW *edit = NULL;
-		/* The middle portion of the window, i.e. the edit window, where
-		 * we display the current file we're editing. */
+		/* The middle portion of the screen: the edit window, showing the
+		 * contents of the current buffer, the file we are editing. */
 WINDOW *bottomwin = NULL;
-		/* The bottom portion of the window, where we display statusbar
+		/* The bottom portion of the screen, where we display statusbar
 		 * messages, the statusbar prompt, and a list of shortcuts. */
 int editwinrows = 0;
 		/* How many rows does the edit window take up? */
+int editwincols = -1;
+		/* The number of usable columns in the edit window: COLS - margin. */
+int margin = 0;
+		/* The amount of space reserved at the left for line numbers. */
 
 filestruct *cutbuffer = NULL;
 		/* The buffer where we store cut text. */
@@ -266,7 +265,7 @@ size_t length_of_list(int menu)
 #define BLANKAFTER  TRUE    /* A blank line after this one. */
 #define TOGETHER  FALSE
 
-/* Just throw this here. */
+/* Empty functions, for the most part corresponding to toggles. */
 void case_sens_void(void)
 {
 }
@@ -291,6 +290,9 @@ void goto_dir_void(void)
 }
 #endif
 #ifndef NANO_TINY
+void do_toggle_void(void)
+{
+}
 void dos_format_void(void)
 {
 }
@@ -318,6 +320,9 @@ void flip_newbuffer(void)
 void discard_buffer(void)
 {
 }
+void do_cancel(void)
+{
+}
 
 /* Add a function to the function list. */
 void add_to_funcs(void (*func)(void), int menus, const char *desc, const char *help,
@@ -392,7 +397,6 @@ const sc *first_sc_for(int menu, void (*func)(void))
 #ifdef DEBUG
 	fprintf(stderr, "Whoops, returning null given func %ld in menu %x\n", (long)func, menu);
 #endif
-	/* Otherwise... */
 	return NULL;
 }
 
@@ -576,6 +580,8 @@ void shortcut_init(void)
 	const char *lastline_gist = N_("Go to the last line of the file");
 #ifndef NANO_TINY
 	const char *bracket_gist = N_("Go to the matching bracket");
+#endif
+#ifdef ENABLE_HELP
 	const char *scrollup_gist =
 		N_("Scroll up one line without moving the cursor textually");
 	const char *scrolldown_gist =
@@ -859,7 +865,7 @@ void shortcut_init(void)
 		prevline_tag, WITHORSANS(prevline_gist), TOGETHER, VIEW);
 	add_to_funcs(do_down, MMAIN|MHELP|MBROWSER,
 		nextline_tag, WITHORSANS(nextline_gist), TOGETHER, VIEW);
-#ifndef NANO_TINY
+#ifdef ENABLE_HELP
 	add_to_funcs(do_scroll_up, MMAIN,
 		N_("Scroll Up"), WITHORSANS(scrollup_gist), TOGETHER, VIEW);
 	add_to_funcs(do_scroll_down, MMAIN,
@@ -1206,7 +1212,7 @@ void shortcut_init(void)
 	add_to_sclist(MMAIN, "M-)", 0, do_para_end_void, 0);
 	add_to_sclist(MMAIN, "M-0", 0, do_para_end_void, 0);
 #endif
-#ifndef NANO_TINY
+#ifdef ENABLE_HELP
 	add_to_sclist(MMAIN, "M--", 0, do_scroll_up, 0);
 	add_to_sclist(MMAIN, "M-_", 0, do_scroll_up, 0);
 	add_to_sclist(MMAIN, "M-+", 0, do_scroll_down, 0);
@@ -1387,8 +1393,7 @@ const subnfunc *sctofunc(const sc *s)
 }
 
 #ifndef NANO_TINY
-/* Now let's come up with a single (hopefully) function to get a string
- * for each flag. */
+/* Return the textual description that corresponds to the given flag. */
 const char *flagtostr(int flag)
 {
 	switch (flag) {
@@ -1526,10 +1531,6 @@ sc *strtosc(const char *input)
 		s->func = do_indent;
 	else if (!strcasecmp(input, "unindent"))
 		s->func = do_unindent;
-	else if (!strcasecmp(input, "scrollup"))
-		s->func = do_scroll_up;
-	else if (!strcasecmp(input, "scrolldown"))
-		s->func = do_scroll_down;
 	else if (!strcasecmp(input, "cutwordleft"))
 		s->func = do_cut_prev_word;
 	else if (!strcasecmp(input, "cutwordright"))
@@ -1559,6 +1560,12 @@ sc *strtosc(const char *input)
 	else if (!strcasecmp(input, "down") ||
 			 !strcasecmp(input, "nextline"))
 		s->func = do_down;
+#ifdef ENABLE_HELP
+	else if (!strcasecmp(input, "scrollup"))
+		s->func = do_scroll_up;
+	else if (!strcasecmp(input, "scrolldown"))
+		s->func = do_scroll_down;
+#endif
 	else if (!strcasecmp(input, "prevword"))
 		s->func = do_prev_word_void;
 	else if (!strcasecmp(input, "nextword"))
